﻿namespace AirplaneWithRadar.MovementStrategy
{
    public abstract class AbstractStrategy
    {
        private IMoveableObject? moveableObject;

        private Status state = Status.NotInit;

        protected int FieldWidth { get; private set; }

        protected int FieldHeight { get; private set; }

        public Status GetStatus() { return state; }

        public void SetData(IMoveableObject moveableObject, int width, int
        height)
        {
            if (moveableObject == null)
            {
                state = Status.NotInit;
                return;
            }
            state = Status.InProgress;
            this.moveableObject = moveableObject;
            FieldWidth = width;
            FieldHeight = height;
        }

        public void MakeStep()
        {
            if (state != Status.InProgress)
            {
                return;
            }
            if (IsTargetDestinaion())
            {
                state = Status.Finish;
                return;
            }
            MoveToTarget();
        }

        protected bool MoveLeft() => MoveTo(Movement.Left);

        protected bool MoveRight() => MoveTo(Movement.Right);

        protected bool MoveUp() => MoveTo(Movement.Up);

        protected bool MoveDown() => MoveTo(Movement.Down);

        protected ObjectParameters? GetObjectParameters => moveableObject?.GetObjectPosition;

        protected int? GetStep()
        {
            if (state != Status.InProgress)
            {
                return null;
            }
            return moveableObject?.GetStep;
        }
        protected abstract void MoveToTarget();

        protected abstract bool IsTargetDestinaion();

        private bool MoveTo(Movement directionType)
        {
            if (state != Status.InProgress)
            {
                return false;
            }
            if (moveableObject?.CheckCanMove(directionType) ?? false)
            {
                moveableObject.MoveObject(directionType);
                return true;
            }
            return false;
        }
    }
}
