﻿using AirplaneWithRadar.Generics;

namespace AirplaneWithRadar
{
    public partial class FormAirplaneCollection : Form
    {
        private readonly AirplanesGenericStorage storage;
        public FormAirplaneCollection()
        {
            InitializeComponent();
            storage = new AirplanesGenericStorage(pictureBoxCollection.Width, pictureBoxCollection.Height);
        }

        private void ReloadObjects()
        {
            int index = listBoxStorages.SelectedIndex;
            listBoxStorages.Items.Clear();
            for (int i = 0; i < storage.Keys.Count; i++)
            {
                listBoxStorages.Items.Add(storage.Keys[i]);
            }
            if (listBoxStorages.Items.Count > 0 && (index == -1 || index >= listBoxStorages.Items.Count))
            {
                listBoxStorages.SelectedIndex = 0;
            }
            else if (listBoxStorages.Items.Count > 0 && index > -1 && index < listBoxStorages.Items.Count)
            {
                listBoxStorages.SelectedIndex = index;
            }
        }
        private void buttonAddObject_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(textBoxStorageName.Text))
            {
                MessageBox.Show("Не все данные заполнены", "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            storage.AddSet(textBoxStorageName.Text);
            ReloadObjects();

        }
        private void listBoxStorages_SelectedIndexChanged(object sender, EventArgs e)
        {
            pictureBoxCollection.Image = storage[listBoxStorages.SelectedItem?.ToString() ?? string.Empty]?.ShowAirplanes();
        }

        private void buttonDelObject_Click(object sender, EventArgs e)
        {
            if (listBoxStorages.SelectedIndex == -1)
            {
                return;
            }
            if (MessageBox.Show($"Удалить объект {listBoxStorages.SelectedItem}?", "Удаление", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes)
{
                storage.DelSet(listBoxStorages.SelectedItem.ToString() ?? string.Empty);
                ReloadObjects();
            }
        }
        private void ButtonAddAirplane_Click(object sender, EventArgs e)
        {
            if (listBoxStorages.SelectedIndex == -1)
            {
                return;
            }
            var obj = storage[listBoxStorages.SelectedItem.ToString() ?? string.Empty];
            if (obj == null)
            {
                return;
            }
            var formAirplaneConfig = new FormAirplaneConfig();

            formAirplaneConfig.AddEvent(airplane =>
            {
                if (listBoxStorages.SelectedIndex != -1)
                {
                    var obj = storage[listBoxStorages.SelectedItem?.ToString() ?? string.Empty];
                    if (obj != null)
                    {
                        if (obj + airplane != 1)
                        {
                            MessageBox.Show("Объект добавлен");
                            pictureBoxCollection.Image = obj.ShowAirplanes();
                        }
                        else
                        {
                            MessageBox.Show("Не удалось добавить объект");
                        }
                    }
                }
            });
            formAirplaneConfig.Show();
        }

        private void ButtonDeleteAirplane_Click(object sender, EventArgs e)
        {
            if (listBoxStorages.SelectedIndex == -1)
            {
                return;
            }
            var obj = storage[listBoxStorages.SelectedItem.ToString() ?? string.Empty];
            if (obj == null)
            {
                return;
            }
            if (MessageBox.Show("Удалить объект?", "Удаление", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.No)
            {
                return;
            }
            int pos = Convert.ToInt32(maskedTextBoxNumber.Text);
            if (obj - pos != false)
            {
                MessageBox.Show("Объект удален");
                pictureBoxCollection.Image = obj.ShowAirplanes();
            }
            else
            {
                MessageBox.Show("Не удалось удалить объект");
            }
        }

        private void ButtonRefreshCollection_Click(object sender, EventArgs e)
        {
            if (listBoxStorages.SelectedIndex == -1)
            {
                return;
            }
            var obj = storage[listBoxStorages.SelectedItem.ToString() ?? string.Empty];
            if (obj == null)
            {
                return;
            }
            pictureBoxCollection.Image = obj.ShowAirplanes();
        }
    }
}
