﻿using AirplaneWithRadar.Entities;

namespace AirplaneWithRadar.PaintObjects
{
    public class PaintAirplaneWithRadar : PaintAirplane
    {
        public AirplaneWithRadarEntity? PlaneEntity { get; private set; }

        public PaintAirplaneWithRadar(int speed, double weight, Color mainColor, Color additColor, bool radarOnBoard, bool additFuelPod, int width, int height)
        : base(speed, weight, mainColor, width, height, 140, 60)
        {
            if (AirplaneEntity != null)
            {
                AirplaneEntity = new AirplaneWithRadarEntity(speed, weight, mainColor, additColor, radarOnBoard, additFuelPod);
            }
        }
        
        public override void DrawTransport(Graphics g)
        {
            if (AirplaneEntity is not AirplaneWithRadarEntity AirplaneWithRadar)
            {
                return;
            }   
            Pen pen = new(Color.Black);
            Brush additBrush = new SolidBrush(AirplaneWithRadar.AdditColor);
            base.DrawTransport(g);
            if (AirplaneWithRadar.RadarOnBoard) {
                g.DrawLine(pen, new Point(startPosX + planeWidth / 3, startPosY + planeHeight / 2), new Point(startPosX + planeWidth / 3, startPosY + planeHeight / 3));
                g.FillPie(additBrush, new Rectangle(startPosX + planeWidth / 4, startPosY + planeHeight / 10, planeWidth / 6, planeHeight / 4), 30.0f, 180.0f);
            }
            if (AirplaneWithRadar.AdditFuelPod)
            {
                FillRoundedRectangle(g, additBrush, new Rectangle(startPosX, startPosY + planeHeight - 2*planeHeight / 5, planeWidth / 5, planeHeight / 6), 5);
            }
            
        }


    }
}
