﻿namespace AirplaneWithRadar.Generics;

internal class SetGeneric<T>
    where T : class
{
    private readonly List<T?> places;
    public int Count => places.Count;
    public readonly int maxCount;
    public SetGeneric(int count)
    {
        maxCount = count;
        places = new List<T?>(count);
    }

    public int Insert(T airplane)
    {
        if (Count == 0)
        {
            places.Add(airplane);
            return 0;
        }
        int emptyPosition = -1;
        for (int i = 0; i < Count; i++)
        {
            if (places[i] == null)
            {
                emptyPosition = i;
                break;
            }
        }
        if (emptyPosition < 0)
        {
            places.Add(airplane);
            return 0;
        }
        Insert(airplane, emptyPosition);
        return 0;
    }
    public int Insert(T airplane, int position)
    {
        if (position > Count || position < 0)
        {
            return -1;
        }
        if (places[position] == null)
        {
            places[position] = airplane;
            return position;
        }

        int emptyPosition = -1;
        for (int i = position + 1; i < Count; i++)
        {
            if (places[i]==null)
            {
                emptyPosition = i;
                break;
            }
        }
        if (emptyPosition < 0)
        {
            return -1;
        }

        for (int i = emptyPosition; i > position; i--)
        {
            places[i] = places[i - 1];
        }

        places[position] = airplane;
        return position;
    }
    public bool Remove(int position)
    {
        if ((position >= Count && position < 0) || places[position] == null)
        {
            return false;
        }
        places[position]=null;
        return true;
    }

    public T? this[int position]
    {
        get
        {
            if (position >= Count || position < 0)
            {
                return null;
            }
            return places[position];
        }
        set
        {
            if (position >= Count || position < 0)
            {
                return;
            }
            if (Count <= maxCount)
            {
                Insert(value, position);
            }
        }
    }
    public IEnumerable<T?> GetAirplanes(int? maxAirplanes = null)
    {
        for (int i = 0; i < places.Count; ++i)
        {
            yield return places[i];
            if (maxAirplanes.HasValue && i == maxAirplanes.Value)
            {
                yield break;
            }
        }
    }
}
